.. currentmodule:: sardana.pool

.. _sardana-ior-overview:

=======================
I/O register overview
=======================

.. todo:: document I/O register overview

.. seealso:: 
    
    :ref:`sardana-ior-api`
        the I/O register :term:`API` 
    
    :class:`~sardana.tango.pool.IORegister.IORegister`
        the I/O register tango device :term:`API`
